@@ -13,8 +13,10 @@ API_PATH = {
     "indicators_fetch_recent": "/api/indicators/fetch/recent/",
     "indicators_fetch_all":    "/api/indicators/fetch/all/",
     "indicators_details":      "/api/indicators/details/{sha256}/",
+    "indicators_pending":      "/api/indicators/pending/",
     "indicators_disabled":     "/api/indicators/disabled/",
-    "indicators_toggle":       "/api/indicators/toggle/",
+    "indicators_enable":       "/api/indicators/enable/",
+    "indicators_disable":      "/api/indicators/disable/",
     "alerts_add":              "/api/alerts/add/",
     "alerts_fetch":            "/api/alerts/fetch/",
     "reports_add":             "/api/reports/add/",
@@ -22,6 +24,6 @@ API_PATH = {
     "reports_details":         "/api/reports/details/{uuid}/",
     "users_pending":           "/api/users/pending/",
     "users_active":            "/api/users/active/",
-    "users_activate":          "/api/users/activate/{api_key}/",
-    "users_deactivate":        "/api/users/deactivate/{api_key}/",
+    "users_activate":          "/api/users/activate/{uuid}/",
+    "users_deactivate":        "/api/users/deactivate/{uuid}/",
 }
