@@ -13,8 +13,19 @@ class PhishDetect:
     def __init__(self, host, api_key=None):
         """Initialize a PhishDetect instance.
 
-        :param host: Host to the PhishDetect Node.
-        :param api_key: The API key to be used to authenticate requests.
+        Args:
+            host (str): Host to the PhishDetect Node.
+            api_key (str): The API key to be used to authenticate requests.
+
+        Returns:
+            The parsed JSON response from the REST API request.
+
+        Examples:
+            ```python
+            import phishdetect
+            pd = phishdetect.PhishDetect(host="https://your-server.com",
+                                         api_key="your-api-key")
+            ```
         """
         self.host = host
         self.api_key = api_key
@@ -29,13 +40,18 @@ class PhishDetect:
 
     def request(self, method, path, data=None, json=None, files=None, params=None):
         """Return the json from the resource requested at ``path``.
-        :param method: HTTP method (mainly GET or POST).
-        :param path: The path to the resource. This will be combined to the host
-                     specified at creation.
-        :param json: Any JSON encoded data to send with the request.
-        :param data: Any data to send as body of the request.
-        :param files: Files to upload.
-        :param params: Query paramaters to send with the request.
+
+        Args:
+            method (str): HTTP method (mainly GET or POST).
+            path (str): The path to the resource. This will be combined to the host
+                specified at creation.
+            json (str): Any JSON encoded data to send with the request.
+            data: Any data to send as body of the request.
+            files: Files to upload.
+            params: Query paramaters to send with the request.
+
+        Returns:
+            The parsed JSON response from the REST API request.
         """
         url = urljoin(self.host, path)
 
@@ -51,23 +67,36 @@ class PhishDetect:
 
     def get(self, path, params=None):
         """Send a GET request and return the JSON response.
-        :param path: Path to the resource to retrieve.
+
+        Args:
+            path (str): Path to the resource to retrieve.
+
+        Returns:
+            The parsed JSON response from the REST API request.
         """
         return self.request(method="GET", path=path, params=params)
 
     def post(self, path, data=None, json=None, files=None, params=None):
         """Send a POST request and return the JSON response.
-        :param path: The path to the resource. This will be combined to the host
-                     specified at creation.
-        :param json: Any JSON encoded data to send with the request.
-        :param data: Any data to send as body of the request.
-        :param files: Files to upload.
-        :param params: Query paramaters to send with the request.
+
+        Args:
+            path (str): The path to the resource. This will be combined to the host
+                specified at creation.
+            json: Any JSON encoded data to send with the request.
+            data: Any data to send as body of the request.
+            files: Files to upload.
+            params: Query paramaters to send with the request.
+
+        Returns:
+            The parsed JSON response from the REST API request.
         """
         return self.request(method="POST", path=path, data=data,
             json=json, files=files, params=params)
 
     def get_config(self):
         """Retrieve the config of specified the PhishDetect Node.
+
+        Returns:
+            The parsed JSON response from the REST API request.
         """
         return self.get(API_PATH["config"])
